@@ -2,21 +2,21 @@ import pandas as pd
 from datetime import timedelta
 
 
-def analyze_df(df: pd.DataFrame, strategy: dict):
+def analyze_df(df: pd.DataFrame, backtest: dict):
     """Analyzes the dataframe and runs sort of a market simulation, entering and exiting positions
 
     Parameters
     ----------
         df, dataframe from process_dataframe after the actions have been added
-        strategy: dict, contains instructions on when to enter/exit trades
+        backtest: dict, contains instructions on when to enter/exit trades
 
     Returns
     -------
         df, returns a dataframe with the new rows processed
     """
     in_trade = False
-    last_base = float(strategy["base_balance"])
-    commission = float(strategy["commission"])
+    last_base = float(backtest["base_balance"])
+    comission = float(backtest["comission"])
     last_aux = 0.0
     new_total_value = last_base
 
@@ -31,10 +31,10 @@ def analyze_df(df: pd.DataFrame, strategy: dict):
         curr_action = row.action
         fee = 0
 
-        if curr_action == "e" and not in_trade:
+        if curr_action in ["e", "ae"] and not in_trade:
             # this means we should enter the trade
             last_aux = convert_base_to_aux(last_base, close)
-            fee = calculate_fee(last_aux, commission)
+            fee = calculate_fee(last_aux, comission)
 
             last_aux = last_aux - fee
             new_total_value = convert_aux_to_base(last_aux, close)
@@ -42,12 +42,15 @@ def analyze_df(df: pd.DataFrame, strategy: dict):
             # should be extremely close to 0
             last_base = round(last_base - new_total_value, 8)
             in_trade = True
+            fee = convert_aux_to_base(fee, close)
 
-        if curr_action == "x" and in_trade:
+        if curr_action in ["x", "ax", "tsl"] and in_trade:
+            # this means we should EXIT the trade
             last_base = convert_aux_to_base(last_aux, close)
-            fee = calculate_fee(last_base, commission)
+            fee = calculate_fee(last_base, comission)
             last_base = last_base - fee
             last_aux = convert_base_to_aux(last_base, close)
+
             new_total_value = last_base
 
             in_trade = False
@@ -58,7 +61,7 @@ def analyze_df(df: pd.DataFrame, strategy: dict):
         in_trade_list.append(in_trade)
         fee_list.append(fee)
 
-    if strategy.get("exit_on_end") and in_trade:
+    if backtest.get("exit_on_end") and in_trade:
         last_base = convert_aux_to_base(last_aux, close)
         last_aux = convert_base_to_aux(last_base, close)
         new_date = df.index[-1] + timedelta(minutes=1)
@@ -84,7 +87,7 @@ def convert_base_to_aux(last_base: float, close: float):
     """converts the base coin to the aux coin
     Parameters
     ----------
-        last_base, the last amount maintained by the strat
+        last_base, the last amount maintained by the backtest
         close, the closing price of the coin
 
     Returns
@@ -100,7 +103,7 @@ def convert_aux_to_base(last_aux: float, close: float):
     """converts the aux coin to the base coin
     Parameters
     ----------
-        last_base, the last amount maintained by the strat
+        last_base, the last amount maintained by the backtest
         close, the closing price of the coin
     Returns
     -------
@@ -111,14 +114,14 @@ def convert_aux_to_base(last_aux: float, close: float):
     return 0.0
 
 
-def calculate_fee(price: float, commission: float):
+def calculate_fee(price: float, comission: float):
     """calculates the trading fees from the exchange
     Parameters
     ----------
         price, amount of the coin after the transaction
-        commission, percentage of the transaction
+        comission, percentage of the transaction
     """
-    if commission:
-        return round((price / 100) * commission, 8)
+    if comission:
+        return round((price / 100) * comission, 8)
 
     return 0.0
